Learn R Programming

lifecontingencies (version 0.0.1)

Exn: Function to evaluate the pure endowment.

Description

Given an actuarial table, this function evaluate the pure endowment.

Usage

Exn(actuarialtable, x, n, type = "EV")

Arguments

actuarialtable
An actuarial table object.
x
Age of the annuity.
n
Number of termso the annuity, if missing annuity is intended to last until death.
type
A string, eithed "EV" (default value), "ST" (stocastic realization) or "VR" if the value of the variance is needed.

Value

  • The value of the pure endowmnet.

Warning

The function is provided as is, without any warranty regarding the accuracy of calculations. The author disclaims any liability for eventual losses arising from direct or indirect use of this software.

Details

As done in all package, interest rate is assumed fixed.

References

Actuarial Mathematics (Second Edition), 1997, by Bowers, N.L., Gerber, H.U., Hickman, J.C., Jones, D.A. and Nesbitt, C.J.

See Also

axn

Examples

Run this code
#assumes SOA example life table to be load
		data(soaLt)
		soa08Act=with(soaLt, new("actuarialtable",interest=0.06,
		x=x,lx=Ix,name="SOA2008"))
		#evaluate the pure endowment for a man aged 30 for a time span of 35
		Exn(soa08Act, x=30, n=35)

Run the code above in your browser using DataLab