View source: R/4_financialFunctions.R
| accumulatedValue | R Documentation |
This function returns the value at time n of a series of equally spaced payments of 1.
accumulatedValue(i, n, m = 0, k = 1, type = "immediate")
i |
Effective interest rate expressed in decimal form. E.g. 0.03 means 3%. |
n |
Number of terms of payment. |
m |
Deferring period, whose default value is zero. |
k |
Frequency of payment. |
type |
The payment type. Use |
The accumulated value is the future value of the terms of an annuity. Its mathematical expression is s_{\left. {\overline {\, n \,}}\! \right| } = {\left( {1 + i} \right)^n} a_{\left. {\overline {\, n \,}}\! \right| }.
The payment timing follows the type argument: an annuity-immediate has payments at the end of each period, while an annuity-due has payments at the beginning of each period.
A numeric value representing the calculated accumulated value.
The function is provided as is, without any guarantee regarding the accuracy of calculation. We disclaim any liability for eventual losses arising from direct or indirect use of this software.
Accumulated values are derived from annuities by the following basic equation {s_{\left. {\overline {\, n \,}}\! \right| }} = {\left( {1 + i} \right)^n} = a_{\left. {\overline {\, n \,}}\! \right| }.
Giorgio A. Spedicato
Broverman, S.A., Mathematics of Investment and Credit (Fourth Edition), 2008, ACTEX Publications.
annuity
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.