Learn R Programming

lifecontingencies (version 0.0.1)

axn: Annuity immediate and due function.

Description

This function calculates actuarial value of annuities, given an actuarial table. Fractional and deferred annuities can be evaluated. Moreover it can be used to simulate the stochastic distribution of the annuity value.

Usage

axn(actuarialtable, x, n, m, k = 1, type = "EV")

Arguments

actuarialtable
An actuarial table object.
x
Age of the annuity.
n
Number of termso the annuity, if missing annuity is intended to last until death.
m
Postponement period, even fractional, if missing assumed to be 1.
k
Number of fractional payments per period, if missing assumed to be 1.
type
A string, eithed "EV" (default value) or "ST" (stocastic realization).

Value

  • A numeric value.

Details

When "ST" has been selected a stochastic value representing a number drawn from the domain of $$a_{x}^{n}$$ is drawn. "EV" calculates the standard stochastic value.

References

Actuarial Mathematics (Second Edition), 1997, by Bowers, N.L., Gerber, H.U., Hickman, J.C., Jones, D.A. and Nesbitt, C.J.

See Also

annuity, Exn

Examples

Run this code
#assumes SOA example life table to be load
		data(soaLt)
		soa08Act=with(soaLt, new("actuarialtable",interest=0.06,
		x=x,lx=Ix,name="SOA2008"))
		#evaluate and life-long annuity for an aged 65
		axn(soa08Act, x=65)

Run the code above in your browser using DataLab