accumulatedValue: Function to evalutate the deterministic accumulated value.
Description
Financial mathematic function to evaluate a series of payments of 1
Usage
accumulatedValue(i, periods, type = "immediate")
Arguments
i
Effective interest rate expressed in decimal form. E.g. 0.03 means 3%.
periods
Number of terms of payment.
type
A string, either "immediate" or "due".
Value
A numeric value representing the calculated cumulated value.
Warning
The function is provided as is, without any guarantee regarding the accuracy of calculation. We disclaim any liability for eventual
losses arising from direct or indirect use of this software.
Details
At the moment no fractional payments have been influenced.
References
Broverman, S.A., Mathematics of Investment and Credit (Fourth Edition),
2008, ACTEX Publications.