View source: R/4_financialFunctions.R
| annuity | R Documentation |
This function calculates the present value of a stream of fixed payments separated by equal intervals of time.
annuity(i, n, m = 0, k = 1, type = "immediate")
i |
Effective interest rate expressed in decimal form. E.g. 0.03 means 3%. It can be a vector of interest rates of the same length of periods. |
n |
Periods for payments. If n = |
m |
Deferring period, whose default value is zero. |
k |
Yearly payments frequency. A payment of |
type |
The payment type. Use |
For an annuity-immediate the first payment occurs at time 1/k; for an annuity-due the first payment occurs at time 0. Thus, for annual payments, an annuity-immediate has payment times 1,2,\ldots,n, whereas an annuity-due has payment times 0,1,\ldots,n-1.
A numeric value representing the present value of the annuity.
The value returned by annuity function derives from direct calculation of the discounted cash flow and not from formulas, like {a^{\left( m \right)}}_{\left. {\overline {\, n \,}}\! \right| } = \frac{{1 - {v^n}}}{{{i^{\left( m \right)}}}}. When m is greater than 1, the payment per period is assumed to be \frac{1}{m}.
Giorgio A. Spedicato
Broverman, S.A., Mathematics of Investment and Credit (Fourth Edition), 2008, ACTEX Publications.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.