decreasingAnnuity: Function to evaluate a decreasing annuity.
Description
This function evalutates decreasing annuities.
Usage
decreasingAnnuity(i, n)
Arguments
i
A numeric value representing the interest rate.
n
The number of periods.
Value
A numeric value reporting the present value of the decreasing cash flows.
Warning
The function is provided as is, without any guarantee regarding the accuracy of calculation. The author disclaims any liability for eventual
losses arising from direct or indirect use of this software.
Details
A decreasing annuity has the following flows of payments: n, n-1, n-2,...
References
Broverman, S.A., Mathematics of Investment and Credit (Fourth Edition),
2008, ACTEX Publications.