increasingAnnuity: Function to evaluate an increasing annuity.
Description
This function evalutates non - stochastic increasing annuities.
Usage
increasingAnnuity(i, n, type = "immediate")
Arguments
i
A numeric value representing the interest rate.
n
The number of periods.
type
Either "immediate" or "due"
Value
The value of the annuity.
Warning
The function is provided as is, without any guarantee regarding the accuracy of calculation. We disclaim any liability for eventual
losses arising from direct or indirect use of this software.
Details
An increasing annuity has the following flows of payments: 1,2,...,n-1,n
References
Broverman, S.A., Mathematics of Investment and Credit (Fourth Edition),
2008, ACTEX Publications.