probs2lifetable: Function to create lifetable object given one given probabilities
Description
This function returns a newly created lifetable object given either
survival or death (one year) probabilities)
Usage
probs2lifetable(probs, radix = 10000, type = "px", name = "ungiven")
Arguments
probs
A real valued vector representing either survival or death (one year) probabilities.
The last value must be either 1 or 0, depending if it represent death or survival probabilities respectively.
radix
The radix of the life table.
type
Character value either "px" or "qx" indicating how probabilities must be interpreted.
name
The character value to be put in the corresponding slot of returned object
Value
A lifetable object.
Warning
The function is provided as is, without any guarantee regarding the accuracy of calculation. We disclaim any liability for eventual
losses arising from direct or indirect use of this software.
Details
The omega value is the length of the probs vector.
References
Actuarial Mathematics (Second Edition), 1997, by Bowers, N.L., Gerber, H.U., Hickman, J.C.,
Jones, D.A. and Nesbitt, C.J.